/**
 * # Quick Search Widget (JS)
 *
 * > A Vanilla JS widget that enables users to perform real-time product searches
 * > with instant results, enhancing product discoverability and conversion.
 *
 * Use this library when you want to display a widget without using a transpiler
 * like Babel and without using JSX. This library exports a `htm` HTML factory
 * to assemble custom elements of the widget.
 *
 * This widget library is version 0.0.15 and the API can change. Please specify
 * exact version when installing.
 *
 * ## Installation {#install}
 *
 * Install `@recombee/quick-search-widget-js@0.0.15` and
 * `recombee-js-api-client` packages using your preferred NPM package manager.
 * This example is using `pnpm`.
 *
 * ```sh
 * pnpm add @recombee/quick-search-widget-js@0.0.15 recombee-js-api-client
 * ```
 *
 * Always remember to apply the default CSS file distributed alongside the
 * widget library, as shown in the examples.
 *
 * ## Client Initialization {#client-initialization}
 *
 * The widget loads recommendation data using [Recombee API Client](/js_client).
 * Here is how to initialize the client with necessary configuration for a
 * specific database:
 *
 * ```ts
 * import { ApiClient } from "recombee-js-api-client";
 *
 * const DATABASE_ID = "[database-id]";
 * const PUBLIC_TOKEN = "[database-public-token]";
 * const REGION = "[database-region]";
 *
 * export const apiClient = new ApiClient(DATABASE_ID, PUBLIC_TOKEN, {
 *   region: REGION,
 * });
 * ```
 *
 * The Database Public Token can be found in the Admin UI
 * {@link https://admin.recombee.com/go-to-database/settings | Database Settings Page}.
 *
 * The widget also needs to be provided a `createRequest` function, which
 * instantiates a client request class to define which data to pull from the
 * database. Use Scenario ID which can be found on Admin GUI
 * {@link https://admin.recombee.com/go-to-database/scenarios | Database Scenarios Page}.
 *
 * ```ts
 * // @noErrors
 * import { type CreateRequestFunction } from "@recombee/carousel-widget-react";
 * import { RecommendItemsToUser } from "recombee-js-api-client";
 *
 * const createRequest: CreateRequestFunction = ({ count }) => {
 *   const SCENARIO_ID = "recommend-items-to-user";
 *   return new RecommendItemsToUser(userId, count, {
 *     scenario: SCENARIO_ID,
 *     cascadeCreate: true,
 *     returnProperties: true,
 *   });
 * };
 * ```
 *
 * Please ensure that you provide the user ID (typically obtained from your
 * existing user tracking system), along with other relevant parameters - such
 * as an item ID or [Item Segment](/segmentations) ID - depending on the
 * specific type of recommendation request.
 *
 * ## Basic Example {#basic-example}
 *
 * The widget in this example uses the {@link DefaultItem} component to render
 * each recommendation in a consistent layout.
 *
 * The resulting widget is inserted into the element specified by the
 * `container` field.
 *
 * Values of the recommended items - such as title, image URL, or link URL - are
 * obtained from the API response and accessed via `props.result?.values`.
 *
 * Ensure that [returnProperties:
 * true](/api#recommend-items-to-user-param-returnProperties) is set in the
 * request, and optionally use
 * [includedProperties](/api#recommend-items-to-user-param-includedProperties)
 * to control which item properties are returned.
 *
 * @example
 *
 * {@includeExample ../examples/basic-example}
 *
 * ## Custom Template {#custom-template}
 *
 * @example
 *
 * {@includeExample ../examples/custom-template}
 *
 * ## Batch Request {#batch-request}
 *
 * To fetch results from multiple Scenarios, such as segments in addition to
 * items, use Batch request.
 *
 * @example
 *
 * {@includeExample ../examples/multiple-requests}
 *
 * @public
 * @packageDocumentation
 */
/** End packageDocumentation */
import { type QuickSearchWidgetProps } from "@recombee/quick-search-widget-react";
export * from "@recombee/quick-search-widget-react";
export * from "htm/react";
/**
 * Quick Search widget
 *
 * @public
 */
export declare const QuickSearchWidget: ({
  container,
  ...props
}: QuickSearchWidgetOptions) => null | undefined;
/**
 * Quick Search widget options
 *
 * @public
 */
export type QuickSearchWidgetOptions = {
  /**
   * CSS Selector to target the element where the widget should be inserted.
   *
   * @public
   */
  container: string;
} & QuickSearchWidgetProps;
//# sourceMappingURL=index.d.ts.map
